@@ -5,6 +5,164 @@
  * @package phpMyAdmin-Navigation
  */
 
+/**
+ * Loads child items of a node and executes a given callback
+ *
+ * @param isNode
+ * @param $expandElem expander
+ * @param callback    callback function
+ *
+ * @returns void
+ */
+function loadChildNodes(isNode, $expandElem, callback) {
+
+    var $destination = null;
+    var params = null;
+
+    if (isNode) {
+        if (!$expandElem.hasClass('expander')) {
+            return;
+        }
+        $destination = $expandElem.closest('li');
+        params = {
+            aPath: $expandElem.find('span.aPath').text(),
+            vPath: $expandElem.find('span.vPath').text(),
+            pos: $expandElem.find('span.pos').text(),
+            pos2_name: $expandElem.find('span.pos2_name').text(),
+            pos2_value: $expandElem.find('span.pos2_value').text(),
+            searchClause: '',
+            searchClause2: ''
+        };
+        if ($expandElem.closest('ul').hasClass('search_results')) {
+            params.searchClause = PMA_fastFilter.getSearchClause();
+            params.searchClause2 = PMA_fastFilter.getSearchClause2($expandElem);
+        }
+    } else {
+        $destination = $('#pma_navigation_tree_content');
+        params = {
+            aPath: $expandElem.attr('aPath'),
+            vPath: $expandElem.attr('vPath'),
+            pos: $expandElem.attr('pos'),
+            pos2_name: '',
+            pos2_value: '',
+            searchClause: '',
+            searchClause2: ''
+        };
+    }
+
+    var url = $('#pma_navigation').find('a.navigation_url').attr('href');
+    $.get(url, params, function (data) {
+        if (typeof data !== 'undefined' && data.success === true) {
+            $destination.find('div.list_container').remove(); // FIXME: Hack, there shouldn't be a list container there
+            if (isNode) {
+                $destination.append(data.message);
+                $expandElem.addClass('loaded');
+            } else {
+                $destination.html(data.message);
+                $destination.children()
+                    .first()
+                    .css({
+                        border: '0px',
+                        margin: '0em',
+                        padding : '0em'
+                    })
+                    .slideDown('slow');
+            }
+            if (data._debug){
+                $('#session_debug').replaceWith(data._debug);
+            }
+            if (data._errors) {
+                $errors = $(data._errors);
+                if ($errors.children().length > 0) {
+                    $('#pma_errors').replaceWith(data._errors);
+                }
+            }
+            if (callback && typeof callback == 'function') {
+                callback(data);
+            }
+        } else if(data.redirect_flag == "1") {
+            window.location.href += '&session_expired=1';
+            window.location.reload();
+        } else {
+            var $throbber = $expandElem.find('img.throbber');
+            $throbber.hide();
+            $icon = $expandElem.find('img.ic_b_plus');
+            $icon.show();
+            PMA_ajaxShowMessage(data.error, false);
+        }
+    });
+}
+
+/**
+ * Collapses a node in navigation tree.
+ *
+ * @param $expandElem expander
+ *
+ * @returns void
+ */
+function collapseTreeNode($expandElem) {
+    var $children = $expandElem.closest('li').children('div.list_container');
+    var $icon = $expandElem.find('img');
+    if ($expandElem.hasClass('loaded')) {
+        if ($icon.is('.ic_b_minus')) {
+            $icon.removeClass('ic_b_minus').addClass('ic_b_plus');
+            $children.slideUp('fast');
+        }
+    }
+    $expandElem.blur();
+    $children.promise().done(navTreeStateUpdate);
+}
+
+/**
+ * Traverse the navigation tree backwards to generate all the actual
+ * and virtual paths, as well as the positions in the pagination at
+ * various levels, if necessary.
+ *
+ * @return Object
+ */
+function traverseNavigationForPaths() {
+    var params = {
+        pos: $('#pma_navigation_tree div.dbselector select').val()
+    };
+    if ($('#navi_db_select').length) {
+        return params;
+    }
+    var count = 0;
+    $('#pma_navigation_tree').find('a.expander:visible').each(function () {
+        if ($(this).find('img').is('.ic_b_minus') &&
+            $(this).closest('li').find('div.list_container .ic_b_minus').length === 0
+        ) {
+            params['n' + count + '_aPath'] = $(this).find('span.aPath').text();
+            params['n' + count + '_vPath'] = $(this).find('span.vPath').text();
+
+            var pos2_name = $(this).find('span.pos2_name').text();
+            if (! pos2_name) {
+                pos2_name = $(this)
+                    .parent()
+                    .parent()
+                    .find('span.pos2_name:last')
+                    .text();
+            }
+            var pos2_value = $(this).find('span.pos2_value').text();
+            if (! pos2_value) {
+                pos2_value = $(this)
+                    .parent()
+                    .parent()
+                    .find('span.pos2_value:last')
+                    .text();
+            }
+
+            params['n' + count + '_pos2_name'] = pos2_name;
+            params['n' + count + '_pos2_value'] = pos2_value;
+
+            params['n' + count + '_pos3_name'] = $(this).find('span.pos3_name').text();
+            params['n' + count + '_pos3_value'] = $(this).find('span.pos3_value').text();
+            count++;
+        }
+    });
+    return params;
+}
+
 /**
  * Executed on page load
  */
@@ -26,7 +184,7 @@ $(function () {
      * opens/closes (hides/shows) tree elements
      * loads data via ajax
      */
-    $('#pma_navigation_tree a.expander').live('click', function (event) {
+    $(document).on('click', '#pma_navigation_tree a.expander', function (event) {
         event.preventDefault();
         event.stopImmediatePropagation();
         var $icon = $(this).find('img');
@@ -41,7 +199,7 @@ $(function () {
      * Register event handler for click on the reload
      * navigation icon at the top of the panel
      */
-    $('#pma_navigation_reload').live('click', function (event) {
+    $(document).on('click', '#pma_navigation_reload', function (event) {
         event.preventDefault();
         // reload icon object
         var $icon = $(this).find('img');
@@ -58,6 +216,10 @@ $(function () {
         }, 1000);
     });
 
+    $(document).on("change", '#navi_db_select',  function (event) {
+        $(this).closest('form').trigger('submit');
+    });
+
     /**
      * Register event handler for click on the collapse all
      * navigation icon at the top of the navigation tree
@@ -134,17 +296,16 @@ $(function () {
     /**
      * Bind all "fast filter" events
      */
-    $('#pma_navigation_tree li.fast_filter span')
-        .live('click', PMA_fastFilter.events.clear);
-    $('#pma_navigation_tree li.fast_filter input.searchClause')
-        .live('focus', PMA_fastFilter.events.focus)
-        .live('blur', PMA_fastFilter.events.blur)
-        .live('keyup', PMA_fastFilter.events.keyup);
+    $(document).on('click', '#pma_navigation_tree li.fast_filter span', PMA_fastFilter.events.clear);
+    $(document).on('focus', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.focus);
+    $(document).on('blur', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.blur);
+    $(document).on('keyup', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.keyup);
+    $(document).on('mouseover', '#pma_navigation_tree li.fast_filter input.searchClause', PMA_fastFilter.events.mouseover);
 
     /**
      * Ajax handler for pagination
      */
-    $('#pma_navigation_tree div.pageselector a.ajax').live('click', function (event) {
+    $(document).on('click', '#pma_navigation_tree div.pageselector a.ajax', function (event) {
         event.preventDefault();
         PMA_navigationTreePagination($(this));
     });
@@ -152,74 +313,74 @@ $(function () {
     /**
      * Node highlighting
      */
-    $('#pma_navigation_tree.highlight li:not(.fast_filter)').live(
+    $(document).on(
         'mouseover',
+        '#pma_navigation_tree.highlight li:not(.fast_filter)',
         function () {
             if ($('li:visible', this).length === 0) {
                 $(this).addClass('activePointer');
             }
         }
     );
-    $('#pma_navigation_tree.highlight li:not(.fast_filter)').live(
+    $(document).on(
         'mouseout',
+        '#pma_navigation_tree.highlight li:not(.fast_filter)',
         function () {
             $(this).removeClass('activePointer');
         }
     );
 
     /** Create a Routine, Trigger or Event */
-    $('li.new_procedure a.ajax, li.new_function a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.new_procedure a.ajax, li.new_function a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
         dialog.editorDialog(1, $(this));
     });
-    $('li.new_trigger a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.new_trigger a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('trigger');
         dialog.editorDialog(1, $(this));
     });
-    $('li.new_event a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.new_event a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('event');
         dialog.editorDialog(1, $(this));
     });
 
     /** Execute Routines */
-    $('li.procedure > a.ajax, li.function > a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.procedure > a.ajax, li.function > a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
         dialog.executeDialog($(this));
     });
     /** Edit Triggers and Events */
-    $('li.trigger > a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.trigger > a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('trigger');
         dialog.editorDialog(0, $(this));
     });
-    $('li.event > a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.event > a.ajax', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('event');
         dialog.editorDialog(0, $(this));
     });
 
     /** Edit Routines */
-    $('li.procedure div a.ajax img,' +
-        ' li.function div a.ajax img').live('click', function (event) {
+    $(document).on('click', 'li.procedure div a.ajax img,' +
+        ' li.function div a.ajax img', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
         dialog.editorDialog(0, $(this).parent());
     });
     /** Export Triggers and Events */
-    $('li.trigger div:eq(1) a.ajax img,' +
-        ' li.event div:eq(1) a.ajax img'
-        ).live('click', function (event) {
+    $(document).on('click', 'li.trigger div:eq(1) a.ajax img, li.event div:eq(1) a.ajax img', function (event) {
         event.preventDefault();
         var dialog = new RTE.object();
         dialog.exportDialog($(this).parent());
     });
 
     /** New index */
-    $('#pma_navigation_tree li.new_index a.ajax').live('click', function (event) {
+    $(document).on('click', '#pma_navigation_tree li.new_index a.ajax', function (event) {
         event.preventDefault();
         var url = $(this).attr('href').substr(
             $(this).attr('href').indexOf('?') + 1
@@ -229,7 +390,7 @@ $(function () {
     });
 
     /** Edit index */
-    $('li.index a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.index a.ajax', function (event) {
         event.preventDefault();
         var url = $(this).attr('href').substr(
             $(this).attr('href').indexOf('?') + 1
@@ -239,13 +400,13 @@ $(function () {
     });
 
     /** New view */
-    $('li.new_view a.ajax').live('click', function (event) {
+    $(document).on('click', 'li.new_view a.ajax', function (event) {
         event.preventDefault();
         PMA_createViewDialog($(this));
     });
 
     /** Hide navigation tree item */
-    $('a.hideNavItem.ajax').live('click', function (event) {
+    $(document).on('click', 'a.hideNavItem.ajax', function (event) {
         event.preventDefault();
         $.ajax({
             url: $(this).attr('href') + '&ajax_request=true',
@@ -260,7 +421,7 @@ $(function () {
     });
 
     /** Display a dialog to choose hidden navigation items to show */
-    $('a.showUnhide.ajax').live('click', function (event) {
+    $(document).on('click', 'a.showUnhide.ajax', function (event) {
         event.preventDefault();
         var $msg = PMA_ajaxShowMessage();
         $.get($(this).attr('href') + '&ajax_request=1', function (data) {
@@ -290,7 +451,7 @@ $(function () {
     });
 
     /** Show a hidden navigation tree item */
-    $('a.unhideNavItem.ajax').live('click', function (event) {
+    $(document).on('click', 'a.unhideNavItem.ajax', function (event) {
         event.preventDefault();
         var $tr = $(this).parents('tr');
         var $msg = PMA_ajaxShowMessage();
@@ -308,12 +469,8 @@ $(function () {
         });
     });
 
-    if ($('#pma_navigation_tree').hasClass('synced')) {
-        PMA_showCurrentNavigation();
-    }
-
     // Add/Remove favorite table using Ajax.
-    $(".favorite_table_anchor").live("click", function (event) {
+    $(document).on("click", ".favorite_table_anchor", function (event) {
         event.preventDefault();
         $self = $(this);
         var anchor_id = $self.attr("id");
@@ -359,17 +516,18 @@ $(function () {
         var storage = window.sessionStorage;
         // remove tree from storage if Navi_panel config form is submitted
         $(document).on('submit', 'form.config-form', function(event) {
-        	storage.removeItem('navTree');
+            storage.removeItem('navTreePaths');
         });
         // Initialize if no previous state is defined
-        if (typeof storage.navTree === 'undefined') {
+        if ($('#pma_navigation_tree_content').length
+            && typeof storage.navTreePaths === 'undefined'
+        ) {
             navTreeStateUpdate();
         } else if (PMA_commonParams.get('server') === storage.server &&
             PMA_commonParams.get('token') === storage.token
         ) {
-            // Restore the tree from storage
-            $('#pma_navigation_tree_content').html(storage.navTree);
-            $('div.pageselector.dbselector').html(storage.page);
+            // Reload the tree to the state before page refresh
+            PMA_reloadNavigation(null, JSON.parse(storage.navTreePaths));
         }
     }
 });
@@ -386,17 +544,15 @@ function navTreeStateUpdate() {
         // try catch necessary here to detect whether
         // content to be stored exceeds storage capacity
         try {
-            storage.setItem('navTree', $('#pma_navigation_tree_content').html());
+            storage.setItem('navTreePaths', JSON.stringify(traverseNavigationForPaths()));
             storage.setItem('server', PMA_commonParams.get('server'));
             storage.setItem('token', PMA_commonParams.get('token'));
-            storage.setItem('page', $('div.pageselector.dbselector').html());
         } catch(error) {
             // storage capacity exceeded & old navigation tree
             // state is no more valid, so remove it
-            storage.removeItem('navTree');
+            storage.removeItem('navTreePaths');
             storage.removeItem('server');
             storage.removeItem('token');
-            storage.removeItem('page');
         }
     }
 }
@@ -430,7 +586,7 @@ function expandTreeNode($expandElem, callback) {
         $icon.hide();
         $throbber.insertBefore($icon);
 
-        loadChildNodes($expandElem, function (data) {
+        loadChildNodes(true, $expandElem, function (data) {
             if (typeof data !== 'undefined' && data.success === true) {
                 var $destination = $expandElem.closest('li');
                 $icon.removeClass('ic_b_plus').addClass('ic_b_minus');
@@ -479,89 +635,6 @@ function scrollToView($element, $forceToTop) {
     }
 }
 
-/**
- * Collapses a node in navigation tree.
- *
- * @param $expandElem expander
- *
- * @returns void
- */
-function collapseTreeNode($expandElem) {
-    var $children = $expandElem.closest('li').children('div.list_container');
-    var $icon = $expandElem.find('img');
-    if ($expandElem.hasClass('loaded')) {
-        if ($icon.is('.ic_b_minus')) {
-            $icon.removeClass('ic_b_minus').addClass('ic_b_plus');
-            $children.slideUp('fast');
-        }
-    }
-    $expandElem.blur();
-    $children.promise().done(navTreeStateUpdate);
-}
-
-/**
- * Loads child items of a node and executes a given callback
- *
- * @param $expandElem expander
- * @param callback    callback function
- *
- * @returns void
- */
-function loadChildNodes($expandElem, callback) {
-    if (!$expandElem.hasClass('expander')) {
-        return;
-    }
-    var $destination = $expandElem.closest('li');
-
-    var searchClause = PMA_fastFilter.getSearchClause();
-    var searchClause2 = PMA_fastFilter.getSearchClause2($expandElem);
-
-    var params = {
-        aPath: $expandElem.find('span.aPath').text(),
-        vPath: $expandElem.find('span.vPath').text(),
-        pos: $expandElem.find('span.pos').text(),
-        pos2_name: $expandElem.find('span.pos2_name').text(),
-        pos2_value: $expandElem.find('span.pos2_value').text(),
-        searchClause: '',
-        searchClause2: ''
-    };
-
-    if ($('#pma_navigation_tree').children().first().is('ul')) {
-        params.searchClause = searchClause;
-        params.searchClause2 = searchClause2;
-    }
-
-    var url = $('#pma_navigation').find('a.navigation_url').attr('href');
-    $.get(url, params, function (data) {
-        if (typeof data !== 'undefined' && data.success === true) {
-            $expandElem.addClass('loaded');
-            $destination.find('div.list_container').remove(); // FIXME: Hack, there shouldn't be a list container there
-            $destination.append(data.message);
-            if (data._debug){
-                $('#session_debug').replaceWith(data._debug);
-            }
-            if (data._errors) {
-                $errors = $(data._errors);
-                if ($errors.children().length > 0) {
-                    $('#pma_errors').replaceWith(data._errors);
-                }
-            }
-            if (callback && typeof callback == 'function') {
-                callback(data);
-            }
-        } else if(data.redirect_flag == "1") {
-            window.location.href += '&session_expired=1';
-            window.location.reload();
-        } else {
-            var $throbber = $expandElem.find('img.throbber');
-            $throbber.hide();
-            $icon = $expandElem.find('img.ic_b_plus');
-            $icon.show();
-            PMA_ajaxShowMessage(data.error, false);
-        }
-    });
-}
-
 /**
  * Expand the navigation and highlight the current database or table/view
  *
@@ -589,6 +662,24 @@ function PMA_showCurrentNavigation() {
             } else {
                 handleTableOrDb(table, $dbItem);
             }
+        } else if ($('#navi_db_select').length
+                && $('option:selected', $('#navi_db_select')).length
+        ) {
+            if (! PMA_selectCurrentDb()) {
+                return;
+            }
+            // If loaded database in navigation is not same as current one
+            if ( $('#pma_navigation_tree_content span.loaded_db:first').text()
+                !== $('#navi_db_select').val()
+            ) {
+                loadChildNodes(false, $('option:selected', $('#navi_db_select')), function (data) {
+                    handleTableOrDb(table, $('#pma_navigation_tree_content'));
+                    var $children = $('#pma_navigation_tree_content').children('div.list_container');
+                    $children.promise().done(navTreeStateUpdate);
+                });
+            } else {
+                handleTableOrDb(table, $('#pma_navigation_tree_content'));
+            }
         }
     }
     PMA_showFullName($('#pma_navigation_tree'));
@@ -601,6 +692,7 @@ function PMA_showCurrentNavigation() {
             var $tableContainer = $container.children('ul').children('li.tableContainer');
             if ($tableContainer.length > 0) {
                 var $expander = $tableContainer.children('div:first').children('a.expander');
+                $tableContainer.addClass('selected');
                 expandTreeNode($expander, function () {
                     scrollToView($dbItem, true);
                 });
@@ -691,7 +783,7 @@ function PMA_showCurrentNavigation() {
     }
 
     function loadAndShowTableOrView($expander, $relatedContainer, itemName) {
-        loadChildNodes($expander, function (data) {
+        loadChildNodes(true, $expander, function (data) {
             var $whichItem = findLoadedItem(
                 $relatedContainer.children('div.list_container'),
                 itemName, null, true
@@ -729,65 +821,52 @@ function PMA_showCurrentNavigation() {
  * Reloads the whole navigation tree while preserving its state
  *
  * @param  function     the callback function
+ * @param  Object       stored navigation paths
+ *
  * @return void
  */
-function PMA_reloadNavigation(callback) {
+function PMA_reloadNavigation(callback, paths) {
     var params = {
-        reload: true,
-        pos: $('#pma_navigation_tree').find('a.expander:first > span.pos').text()
+        reload: true
     };
-    // Traverse the navigation tree backwards to generate all the actual
-    // and virtual paths, as well as the positions in the pagination at
-    // various levels, if necessary.
-    var count = 0;
-    $('#pma_navigation_tree').find('a.expander:visible').each(function () {
-        if ($(this).find('img').is('.ic_b_minus') &&
-            $(this).closest('li').find('div.list_container .ic_b_minus').length === 0
-        ) {
-            params['n' + count + '_aPath'] = $(this).find('span.aPath').text();
-            params['n' + count + '_vPath'] = $(this).find('span.vPath').text();
+    paths = paths || traverseNavigationForPaths();
+    $.extend(params, paths);
+    if ($('#navi_db_select').length) {
+        params.db = PMA_commonParams.get('db');
+        requestNaviReload(params);
+        return;
+    }
+    requestNaviReload(params);
 
-            var pos2_name = $(this).find('span.pos2_name').text();
-            if (! pos2_name) {
-                pos2_name = $(this)
-                    .parent()
-                    .parent()
-                    .find('span.pos2_name:last')
-                    .text();
-            }
-            var pos2_value = $(this).find('span.pos2_value').text();
-            if (! pos2_value) {
-                pos2_value = $(this)
-                    .parent()
-                    .parent()
-                    .find('span.pos2_value:last')
-                    .text();
+    function requestNaviReload(params) {
+        var url = $('#pma_navigation').find('a.navigation_url').attr('href');
+        $.post(url, params, function (data) {
+            if (typeof data !== 'undefined' && data.success) {
+                $('#pma_navigation_tree').html(data.message).children('div').show();
+                if ($('#pma_navigation_tree').hasClass('synced')) {
+                    PMA_selectCurrentDb();
+                    PMA_showCurrentNavigation();
+                }
+                // Fire the callback, if any
+                if (typeof callback === 'function') {
+                    callback.call();
+                }
+                navTreeStateUpdate();
+            } else {
+                PMA_ajaxShowMessage(data.error);
             }
+        });
+    }
+}
 
-            params['n' + count + '_pos2_name'] = pos2_name;
-            params['n' + count + '_pos2_value'] = pos2_value;
-
-            params['n' + count + '_pos3_name'] = $(this).find('span.pos3_name').text();
-            params['n' + count + '_pos3_value'] = $(this).find('span.pos3_value').text();
-            count++;
+function PMA_selectCurrentDb() {
+    if ($('#navi_db_select').length) {
+        $('#navi_db_select').val(PMA_commonParams.get('db'));
+        if ($('#navi_db_select').val() !== PMA_commonParams.get('db')) {
+            return false;
         }
-    });
-    var url = $('#pma_navigation').find('a.navigation_url').attr('href');
-    $.post(url, params, function (data) {
-        if (typeof data !== 'undefined' && data.success) {
-            $('#pma_navigation_tree').html(data.message).children('div').show();
-            if ($('#pma_navigation_tree').hasClass('synced')) {
-                PMA_showCurrentNavigation();
-            }
-            // Fire the callback, if any
-            if (typeof callback === 'function') {
-                callback.call();
-            }
-            navTreeStateUpdate();
-        } else {
-            PMA_ajaxShowMessage(data.error);
-        }
-    });
+        return true;
+    }
 }
 
 /**
@@ -996,8 +1075,8 @@ var ResizeHandler = function () {
         event.preventDefault();
         var pos = event.data.resize_handler.getPos(event);
         event.data.resize_handler.setWidth(pos);
-        if($('#sticky_columns').length !== 0) {
-            handleStickyColumns();
+        if ($('.sticky_columns').length !== 0) {
+            handleAllStickyColumns();
         }
     };
     /**
@@ -1037,8 +1116,7 @@ var ResizeHandler = function () {
             });
         }
         // Set content bottom space beacuse of console
-        $('body').css('margin-bottom',
-                      $(window).height() + $(document).scrollTop() - $('#pma_console').offset().top + 'px');
+        $('body').css('margin-bottom', $('#pma_console').height() + 'px');
     };
     /* Initialisation section begins here */
     if ($.cookie('pma_navi_width')) {
@@ -1048,12 +1126,11 @@ var ResizeHandler = function () {
         $('#topmenu').menuResizer('resize');
     }
     // Register the events for the resizer and the collapser
-    $('#pma_navigation_resizer')
-        .live('mousedown', {'resize_handler': this}, this.mousedown);
-    var $collapser = $('#pma_navigation_collapser');
-    $collapser.live('click', {'resize_handler': this}, this.collapse);
+    $(document).on('mousedown', '#pma_navigation_resizer', {'resize_handler': this}, this.mousedown);
+    $(document).on('click', '#pma_navigation_collapser', {'resize_handler': this}, this.collapse);
+
     // Add the correct arrow symbol to the collapser
-    $collapser.html(this.getSymbol($('#pma_navigation').width()));
+    $('#pma_navigation_collapser').html(this.getSymbol($('#pma_navigation').width()));
     // Fix navigation tree height
     $(window).on('resize', this.treeResize);
     // need to call this now and then, browser might decide
@@ -1092,10 +1169,6 @@ var PMA_fastFilter = {
          *                    the fast filter was applied
          */
         this.$clone = $this.clone();
-        /**
-         * @var bool swapped Whether the user clicked on the "N other results" link
-         */
-        this.swapped = false;
         /**
          * @var object xhr A reference to the ajax request that is currently running
          */
@@ -1178,6 +1251,26 @@ var PMA_fastFilter = {
                 $obj.data('fastFilter').restore();
             }
         },
+        mouseover: function (event) {
+            var message = '';
+            if ($(this).closest('li.fast_filter').is('.db_fast_filter')) {
+                message = PMA_messages.strHoverDbFastFilter;
+            } else {
+                var node_type = $(this).siblings("input[name='pos2_name']").val();
+                var node_name = PMA_messages.strTables;
+                if (node_type == 'views') {
+                    node_name = PMA_messages.strViews;
+                } else if (node_type == 'procedures') {
+                    node_name = PMA_messages.strProcedures;
+                } else if (node_type == 'functions') {
+                    node_name = PMA_messages.strFunctions;
+                } else if (node_type == 'events') {
+                    node_name = PMA_messages.strEvents;
+                }
+                message = PMA_sprintf(PMA_messages.strHoverFastFilter, node_name);
+            }
+            PMA_tooltip($(this), 'input', message);
+        },
         keyup: function (event) {
             var $obj = $(this).closest('div.list_container');
             var str = '';
@@ -1249,7 +1342,9 @@ var PMA_fastFilter = {
                         new PMA_fastFilter.filter($obj, $(this).val())
                     );
                 } else {
-                    $obj.data('fastFilter').update($(this).val());
+                    if (event.keyCode == 13) {
+                        $obj.data('fastFilter').update($(this).val());
+                    }
                 }
             } else if ($obj.data('fastFilter')) {
                 $obj.data('fastFilter').restore(true);
@@ -1277,7 +1372,6 @@ var PMA_fastFilter = {
 PMA_fastFilter.filter.prototype.update = function (searchClause) {
     if (this.searchClause != searchClause) {
         this.searchClause = searchClause;
-        this.$this.find('.moreResults').remove();
         this.request();
     }
 };
@@ -1289,7 +1383,6 @@ PMA_fastFilter.filter.prototype.update = function (searchClause) {
  */
 PMA_fastFilter.filter.prototype.request = function () {
     var self = this;
-    clearTimeout(self.timeout);
     if (self.$this.find('li.fast_filter').find('img.throbber').length === 0) {
         self.$this.find('li.fast_filter').append(
             $('<div class="throbber"></div>').append(
@@ -1300,43 +1393,32 @@ PMA_fastFilter.filter.prototype.request = function () {
             )
         );
     }
-    self.timeout = setTimeout(function () {
-        if (self.xhr) {
-            self.xhr.abort();
+    if (self.xhr) {
+        self.xhr.abort();
+    }
+    var url = $('#pma_navigation').find('a.navigation_url').attr('href');
+    var params = self.$this.find('> ul > li > form.fast_filter').first().serialize();
+    if (self.$this.find('> ul > li > form.fast_filter:first input[name=searchClause]').length === 0) {
+        var $input = $('#pma_navigation_tree').find('li.fast_filter.db_fast_filter input.searchClause');
+        if ($input.length && $input.val() != $input[0].defaultValue) {
+            params += '&searchClause=' + encodeURIComponent($input.val());
         }
-        var url = $('#pma_navigation').find('a.navigation_url').attr('href');
-        var results = self.$this.find('li:not(.hidden):not(.fast_filter):not(.navGroup):not(#navigation_controls_outer)').not('[class^=new]').not('[class^=warp_link]').length;
-        var params = self.$this.find('> ul > li > form.fast_filter').first().serialize() + "&results=" + results;
-        if (self.$this.find('> ul > li > form.fast_filter:first input[name=searchClause]').length === 0) {
-            var $input = $('#pma_navigation_tree').find('li.fast_filter.db_fast_filter input.searchClause');
-            if ($input.length && $input.val() != $input[0].defaultValue) {
-                params += '&searchClause=' + encodeURIComponent($input.val());
-            }
-        }
-        self.xhr = $.ajax({
-            url: url,
-            type: 'post',
-            dataType: 'json',
-            data: params,
-            complete: function (jqXHR, status) {
-                if (status != 'abort') {
-                    var data = $.parseJSON(jqXHR.responseText);
-                    self.$this.find('li.fast_filter').find('div.throbber').remove();
-                    if (data && data.results) {
-                        var $listItem = $('<li />', {'class': 'moreResults'})
-                            .appendTo(self.$this.find('li.fast_filter'));
-                        $('<a />', {href: '#'})
-                            .text(data.results)
-                            .appendTo($listItem)
-                            .click(function (event) {
-                                event.preventDefault();
-                                self.swap.apply(self, [data.message]);
-                            });
-                    }
+    }
+    self.xhr = $.ajax({
+        url: url,
+        type: 'post',
+        dataType: 'json',
+        data: params,
+        complete: function (jqXHR, status) {
+            if (status != 'abort') {
+                var data = $.parseJSON(jqXHR.responseText);
+                self.$this.find('li.fast_filter').find('div.throbber').remove();
+                if (data && data.results) {
+                    self.swap.apply(self, [data.message]);
                 }
             }
-        });
-    }, 250);
+        }
+    });
 };
 /**
  * Replaces the contents of the navigation branch with the search results
@@ -1346,7 +1428,6 @@ PMA_fastFilter.filter.prototype.request = function () {
  * @return void
  */
 PMA_fastFilter.filter.prototype.swap = function (list) {
-    this.swapped = true;
     this.$this
         .html($(list).html())
         .children()
@@ -1364,8 +1445,7 @@ PMA_fastFilter.filter.prototype.swap = function (list) {
  * @return void
  */
 PMA_fastFilter.filter.prototype.restore = function (focus) {
-    if (this.swapped) {
-        this.swapped = false;
+    if(this.$this.children('ul').first().hasClass('search_results')) {
         this.$this.html(this.$clone.html()).children().show();
         this.$this.data('fastFilter', this);
         if (focus) {
@@ -1373,7 +1453,6 @@ PMA_fastFilter.filter.prototype.restore = function (focus) {
         }
     }
     this.searchClause = '';
-    this.$this.find('.moreResults').remove();
     this.$this.find('div.pageselector').show();
     this.$this.find('div.throbber').remove();
 };
